#
# spec file for package python-pandas-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pandas-doc
Version:        0.22.0
Release:        lp150.1.18
Summary:        Documentation for python-pandas
License:        BSD-3-Clause
Group:          Documentation/HTML
Url:            http://pandas.pydata.org/
Source0:        https://files.pythonhosted.org/packages/source/p/pandas/pandas-%{version}.tar.gz
BuildRequires:  %{python_module pandas = %{version}}
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-jupyter_client
BuildRequires:  python3-jupyter_ipykernel
BuildRequires:  python3-jupyter_nbconvert
BuildRequires:  python3-jupyter_nbformat
BuildRequires:  python3-jupyter_nbsphinx
BuildRequires:  python3-matplotlib
BuildRequires:  python3-numpy-devel >= 1.7.1
BuildRequires:  python3-python-dateutil >= 1.5
BuildRequires:  python3-pytz
BuildRequires:  python3-scipy
BuildRequires:  python3-setuptools
Provides:       %{python_module pandas-doc = %{version}}
BuildArch:      noarch

%description
Documentation, help files, and examples for python3-pandas.

%prep
%setup -q -n pandas-%{version}

%build
python3 setup.py build_ext --inplace

pushd doc
python3 make.py html
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-pandas
cp -r doc/build/html %{buildroot}%{_docdir}/python-pandas/

%files
%doc LICENSE
%{_docdir}/python-pandas/

%changelog
* Thu Jan 11 2018 tchvatal@suse.com
- Format with spec-cleaner
* Wed Jan  3 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.22.0:
  * Pandas 0.22.0 changes the handling of empty and all-NA sums and
    products. The summary is that
    + The sum of an empty or all-NA Series is now 0
    + The product of an empty or all-NA Series is now 1
    + We’ve added a min_count parameter to .sum() and .prod()
    controlling the minimum number of valid values for the result to
    be valid. If fewer than min_count non-NA values are present, the
    result is NA. The default is 0. To return NaN, the 0.21
    behavior, use min_count=1.
* Sat Dec 16 2017 arun@gmx.de
- update to version 0.21.1:
  * Highlights include:
    + Temporarily restore matplotlib datetime plotting
    functionality. This should resolve issues for users who
    implicitly relied on pandas to plot datetimes with
    matplotlib. See here.
    + Improvements to the Parquet IO functions introduced in
    0.21.0. See here.
  * Improvements to the Parquet IO functionality
    + DataFrame.to_parquet() will now write non-default indexes when
    the underlying engine supports it. The indexes will be preserved
    when reading back in with read_parquet() (GH18581).
    + read_parquet() now allows to specify the columns to read from a
    parquet file (GH18154)
    + read_parquet() now allows to specify kwargs which are passed to
    the respective engine (GH18216)
  * Other Enhancements
    + Timestamp.timestamp() is now available in Python 2.7. (GH17329)
    + Grouper and TimeGrouper now have a friendly repr output
    (GH18203).
  * Deprecations
    + pandas.tseries.register has been renamed to
    pandas.plotting.register_matplotlib_converters`() (GH18301)
  * Performance Improvements
    + Improved performance of plotting large series/dataframes
    (GH18236).
  * Conversion
    + Bug in TimedeltaIndex subtraction could incorrectly overflow
    when NaT is present (GH17791)
    + Bug in DatetimeIndex subtracting datetimelike from DatetimeIndex
    could fail to overflow (GH18020)
    + Bug in IntervalIndex.copy() when copying and IntervalIndex with
    non-default closed (GH18339)
    + Bug in DataFrame.to_dict() where columns of datetime that are
    tz-aware were not converted to required arrays when used with
    orient='records', raising"TypeError` (GH18372)
    + Bug in DateTimeIndex and date_range() where mismatching tz-aware
    start and end timezones would not raise an err if end.tzinfo is
    None (GH18431)
    + Bug in Series.fillna() which raised when passed a long integer
    on Python 2 (GH18159).
  * Indexing
    + Bug in a boolean comparison of a datetime.datetime and a
    datetime64[ns] dtype Series (GH17965)
    + Bug where a MultiIndex with more than a million records was not
    raising AttributeError when trying to access a missing attribute
    (GH18165)
    + Bug in IntervalIndex constructor when a list of intervals is
    passed with non-default closed (GH18334)
    + Bug in Index.putmask when an invalid mask passed (GH18368)
    + Bug in masked assignment of a timedelta64[ns] dtype Series,
    incorrectly coerced to float (GH18493)
  * I/O
    + Bug in class:~pandas.io.stata.StataReader not converting
    date/time columns with display formatting addressed
    (GH17990). Previously columns with display formatting were
    normally left as ordinal numbers and not converted to datetime
    objects.
    + Bug in read_csv() when reading a compressed UTF-16 encoded file
    (GH18071)
    + Bug in read_csv() for handling null values in index columns when
    specifying na_filter=False (GH5239)
    + Bug in read_csv() when reading numeric category fields with high
    cardinality (GH18186)
    + Bug in DataFrame.to_csv() when the table had MultiIndex columns,
    and a list of strings was passed in for header (GH5539)
    + Bug in parsing integer datetime-like columns with specified
    format in read_sql (GH17855).
    + Bug in DataFrame.to_msgpack() when serializing data of the
    numpy.bool_ datatype (GH18390)
    + Bug in read_json() not decoding when reading line deliminted
    JSON from S3 (GH17200)
    + Bug in pandas.io.json.json_normalize() to avoid modification of
    meta (GH18610)
    + Bug in to_latex() where repeated multi-index values were not
    printed even though a higher level index differed from the
    previous row (GH14484)
    + Bug when reading NaN-only categorical columns in HDFStore
    (GH18413)
    + Bug in DataFrame.to_latex() with longtable=True where a latex
    multicolumn always spanned over three columns (GH17959)
  * Plotting
    + Bug in DataFrame.plot() and Series.plot() with DatetimeIndex
    where a figure generated by them is not pickleable in Python 3
    (GH18439)
  * Groupby/Resample/Rolling
    + Bug in DataFrame.resample(...).apply(...) when there is a
    callable that returns different columns (GH15169)
    + Bug in DataFrame.resample(...) when there is a time change (DST)
    and resampling frequecy is 12h or higher (GH15549)
    + Bug in pd.DataFrameGroupBy.count() when counting over a
    datetimelike column (GH13393)
    + Bug in rolling.var where calculation is inaccurate with a
    zero-valued array (GH18430)
  * Reshaping
    + Error message in pd.merge_asof() for key datatype mismatch now
    includes datatype of left and right key (GH18068)
    + Bug in pd.concat when empty and non-empty DataFrames or Series
    are concatenated (GH18178 GH18187)
    + Bug in DataFrame.filter(...) when unicode is passed as a
    condition in Python 2 (GH13101)
    + Bug when merging empty DataFrames when np.seterr(divide='raise')
    is set (GH17776)
  * Numeric
    + Bug in pd.Series.rolling.skew() and rolling.kurt() with all
    equal values has floating issue (GH18044)
    + Bug in TimedeltaIndex subtraction could incorrectly overflow
    when NaT is present (GH17791)
    + Bug in DatetimeIndex subtracting datetimelike from DatetimeIndex
    could fail to overflow (GH18020)
  * Categorical
    + Bug in DataFrame.astype() where casting to ‘category’ on an
    empty DataFrame causes a segmentation fault (GH18004)
    + Error messages in the testing module have been improved when
    items have different CategoricalDtype (GH18069)
    + CategoricalIndex can now correctly take a
    pd.api.types.CategoricalDtype as its dtype (GH18116)
    + Bug in Categorical.unique() returning read-only codes array when
    all categories were NaN (GH18051)
    + Bug in DataFrame.groupby(axis=1) with a CategoricalIndex
    (GH18432)
  * String
    + Series.str.split() will now propogate NaN values across all
    expanded columns instead of None (GH18450)
* Mon Oct 30 2017 arun@gmx.de
- specfile:
  * updated minimum numpy version to 1.9.0 (see setup.py)
- update to version 0.21.0:
  * Highlights include:
    + Integration with Apache Parquet, including a new top-level
    read_parquet() function and DataFrame.to_parquet() method, see
    here.
    + New user-facing pandas.api.types.CategoricalDtype for specifying
    categoricals independent of the data, see here.
    + The behavior of sum and prod on all-NaN Series/DataFrames is now
    consistent and no longer depends on whether bottleneck is
    installed, see here.
    + Compatibility fixes for pypy, see here.
    + Additions to the drop, reindex and rename API to make them more
    consistent, see here.
    + Addition of the new methods DataFrame.infer_objects (see here)
    and GroupBy.pipe (see here).
    + Indexing with a list of labels, where one or more of the labels
    is missing, is deprecated and will raise a KeyError in a future
    version, see here.
  * full list at http://pandas.pydata.org/pandas-docs/stable/whatsnew.html
* Sat Sep 23 2017 arun@gmx.de
- update to version 0.20.3:
  * bug fix release, see http://pandas.pydata.org/pandas-docs/stable/whatsnew.html#v0-20-3-july-7-2017
    for complete changelog
- changes from version 0.20.2:
  * bug fix release, see http://pandas.pydata.org/pandas-docs/stable/whatsnew.html#v0-20-2-june-4-2017
    for complete changelog
* Tue May 30 2017 toddrme2178@gmail.com
- Fix documentation BuildRequires.
* Thu May 18 2017 toddrme2178@gmail.com
- Update to version 0.20.1
  Highlights include:
  * New ``.agg()`` API for Series/DataFrame similar to the
    groupby-rolling-resample API's
  * Integration with the ``feather-format``, including a new
    top-level ``pd.read_feather()`` and ``DataFrame.to_feather()``
    method
  * The ``.ix`` indexer has been deprecated
  * ``Panel`` has been deprecated
  * Addition of an ``IntervalIndex`` and ``Interval`` scalar type
  * Improved user API when grouping by index levels in ``.groupby()``
  * Improved support for ``UInt64`` dtypes
  * A new orient for JSON serialization, ``orient='table'``, that
    uses the Table Schema spec and that gives the possibility for
    a more interactive repr in the Jupyter Notebook
  * Experimental support for exporting styled DataFrames
    (``DataFrame.style``) to Excel
  * Window binary corr/cov operations now return a MultiIndexed
    ``DataFrame`` rather than a ``Panel``, as ``Panel`` is now
    deprecated
  * Support for S3 handling now uses ``s3fs``
  * Google BigQuery support now uses the ``pandas-gbq`` library
* Tue Apr 25 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- update to version 0.19.2:
  * Enhancements
    The pd.merge_asof(), added in 0.19.0, gained some improvements:
    + pd.merge_asof() gained left_index/right_index and
    left_by/right_by arguments (GH14253)
    + pd.merge_asof() can take multiple columns in by parameter and
    has specialized dtypes for better performace (GH13936)
  * Performance Improvements
    + Performance regression with PeriodIndex (GH14822)
    + Performance regression in indexing with getitem (GH14930)
    + Improved performance of .replace() (GH12745)
    + Improved performance Series creation with a datetime index and
    dictionary data (GH14894)
  * Bug Fixes
    + Compat with python 3.6 for pickling of some offsets (GH14685)
    + Compat with python 3.6 for some indexing exception types
    (GH14684, GH14689)
    + Compat with python 3.6 for deprecation warnings in the test
    suite (GH14681)
    + Compat with python 3.6 for Timestamp pickles (GH14689)
    + Compat with dateutil==2.6.0; segfault reported in the testing
    suite (GH14621)
    + Allow nanoseconds in Timestamp.replace as a kwarg (GH14621)
    + Bug in pd.read_csv in which aliasing was being done for
    na_values when passed in as a dictionary (GH14203)
    + Bug in pd.read_csv in which column indices for a dict-like
    na_values were not being respected (GH14203)
    + Bug in pd.read_csv where reading files fails, if the number of
    headers is equal to the number of lines in the file (GH14515)
    + Bug in pd.read_csv for the Python engine in which an unhelpful
    error message was being raised when multi-char delimiters were
    not being respected with quotes (GH14582)
    + Fix bugs (GH14734, GH13654) in pd.read_sas and
    pandas.io.sas.sas7bdat.SAS7BDATReader that caused problems when
    reading a SAS file incrementally.
    + Bug in pd.read_csv for the Python engine in which an unhelpful
    error message was being raised when skipfooter was not being
    respected by Python’s CSV library (GH13879)
    + Bug in .fillna() in which timezone aware datetime64 values were
    incorrectly rounded (GH14872)
    + Bug in .groupby(..., sort=True) of a non-lexsorted MultiIndex
    when grouping with multiple levels (GH14776)
    + Bug in pd.cut with negative values and a single bin (GH14652)
    + Bug in pd.to_numeric where a 0 was not unsigned on a
    downcast='unsigned' argument (GH14401)
    + Bug in plotting regular and irregular timeseries using shared
    axes (sharex=True or ax.twinx()) (GH13341, GH14322).
    + Bug in not propogating exceptions in parsing invalid datetimes,
    noted in python 3.6 (GH14561)
    + Bug in resampling a DatetimeIndex in local TZ, covering a DST
    change, which would raise AmbiguousTimeError (GH14682)
    + Bug in indexing that transformed RecursionError into KeyError or
    IndexingError (GH14554)
    + Bug in HDFStore when writing a MultiIndex when using
    data_columns=True (GH14435)
    + Bug in HDFStore.append() when writing a Series and passing a
    min_itemsize argument containing a value for the index (GH11412)
    + Bug when writing to a HDFStore in table format with a
    min_itemsize value for the index and without asking to append
    (GH10381)
    + Bug in Series.groupby.nunique() raising an IndexError for an
    empty Series (GH12553)
    + Bug in DataFrame.nlargest and DataFrame.nsmallest when the index
    had duplicate values (GH13412)
    + Bug in clipboard functions on linux with python2 with unicode
    and separators (GH13747)
    + Bug in clipboard functions on Windows 10 and python 3 (GH14362,
    GH12807)
    + Bug in .to_clipboard() and Excel compat (GH12529)
    + Bug in DataFrame.combine_first() for integer columns (GH14687).
    + Bug in pd.read_csv() in which the dtype parameter was not being
    respected for empty data (GH14712)
    + Bug in pd.read_csv() in which the nrows parameter was not being
    respected for large input when using the C engine for parsing
    (GH7626)
    + Bug in pd.merge_asof() could not handle timezone-aware
    DatetimeIndex when a tolerance was specified (GH14844)
    + Explicit check in to_stata and StataWriter for out-of-range
    values when writing doubles (GH14618)
    + Bug in .plot(kind='kde') which did not drop missing values to
    generate the KDE Plot, instead generating an empty
    plot. (GH14821)
    + Bug in unstack() if called with a list of column(s) as an
    argument, regardless of the dtypes of all columns, they get
    coerced to object (GH11847)
- update to version 0.19.1:
  * Performance Improvements
    + Fixed performance regression in factorization of Period data
    (GH14338)
    + Fixed performance regression in Series.asof(where) when where is
    a scalar (GH14461)
    + Improved performance in DataFrame.asof(where) when where is a
    scalar (GH14461)
    + Improved performance in .to_json() when lines=True (GH14408)
    + Improved performance in certain types of loc indexing with a
    MultiIndex (GH14551).
  * Bug Fixes
    + Source installs from PyPI will now again work without cython
    installed, as in previous versions (GH14204)
    + Compat with Cython 0.25 for building (GH14496)
    + Fixed regression where user-provided file handles were closed in
    read_csv (c engine) (GH14418).
    + Fixed regression in DataFrame.quantile when missing values where
    present in some columns (GH14357).
    + Fixed regression in Index.difference where the freq of a
    DatetimeIndex was incorrectly set (GH14323)
    + Added back pandas.core.common.array_equivalent with a
    deprecation warning (GH14555).
    + Bug in pd.read_csv for the C engine in which quotation marks
    were improperly parsed in skipped rows (GH14459)
    + Bug in pd.read_csv for Python 2.x in which Unicode quote
    characters were no longer being respected (GH14477)
    + Fixed regression in Index.append when categorical indices were
    appended (GH14545).
    + Fixed regression in pd.DataFrame where constructor fails when
    given dict with None value (GH14381)
    + Fixed regression in DatetimeIndex._maybe_cast_slice_bound when
    index is empty (GH14354).
    + Bug in localizing an ambiguous timezone when a boolean is passed
    (GH14402)
    + Bug in TimedeltaIndex addition with a Datetime-like object where
    addition overflow in the negative direction was not being caught
    (GH14068, GH14453)
    + Bug in string indexing against data with object Index may raise
    AttributeError (GH14424)
    + Corrrecly raise ValueError on empty input to pd.eval() and
    df.query() (GH13139)
    + Bug in RangeIndex.intersection when result is a empty set
    (GH14364).
    + Bug in groupby-transform broadcasting that could cause incorrect
    dtype coercion (GH14457)
    + Bug in Series.__setitem__ which allowed mutating read-only
    arrays (GH14359).
    + Bug in DataFrame.insert where multiple calls with duplicate
    columns can fail (GH14291)
    + pd.merge() will raise ValueError with non-boolean parameters in
    passed boolean type arguments (GH14434)
    + Bug in Timestamp where dates very near the minimum (1677-09)
    could underflow on creation (GH14415)
    + Bug in pd.concat where names of the keys were not propagated to
    the resulting MultiIndex (GH14252)
    + Bug in pd.concat where axis cannot take string parameters 'rows'
    or 'columns' (GH14369)
    + Bug in pd.concat with dataframes heterogeneous in length and
    tuple keys (GH14438)
    + Bug in MultiIndex.set_levels where illegal level values were
    still set after raising an error (GH13754)
    + Bug in DataFrame.to_json where lines=True and a value contained
    a } character (GH14391)
    + Bug in df.groupby causing an AttributeError when grouping a
    single index frame by a column and the index level
    (:issue`14327`)
    + Bug in df.groupby where TypeError raised when
    pd.Grouper(key=...) is passed in a list (GH14334)
    + Bug in pd.pivot_table may raise TypeError or ValueError when
    index or columns is not scalar and values is not specified
    (GH14380)
* Mon Mar 27 2017 toddrme2178@gmail.com
- Fix documentation building
* Sun Oct 23 2016 toddrme2178@gmail.com
- update to version 0.19.0:
  (long changelog, see http://pandas.pydata.org/pandas-docs/stable/whatsnew.html#v0-19-0-october-2-2016)
  * Highlights include:
    + merge_asof() for asof-style time-series joining
    + .rolling() is now time-series aware
    + read_csv() now supports parsing Categorical data
    + A function union_categorical() has been added for combining
    categoricals
    + PeriodIndex now has its own period dtype, and changed to be more
    consistent with other Index classes
    + Sparse data structures gained enhanced support of int and bool
    dtypes
    + Comparison operations with Series no longer ignores the index,
    see here for an overview of the API changes.
    + Introduction of a pandas development API for utility functions
    + Deprecation of Panel4D and PanelND. We recommend to represent
    these types of n-dimensional data with the xarray package.
    + Removal of the previously deprecated modules pandas.io.data,
    pandas.io.wb, pandas.tools.rplot.
- specfile:
  * require python3-Cython
  * Split documentation into own subpackage to speed up build.
  * Remove buildrequires for optional dependencies to speed up build.
- Remove unneeded patches:
  * 0001_disable_experimental_msgpack_big_endian.patch ^
  * 0001_respect_byteorder_in_statareader.patch
